@@ -10,8 +10,7 @@
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU Affero General Public License as        *
- *   published by the Free Software Foundation, either version 3 of the    *
- *   License, or (at your option) any later version.                       *
+ *   published by the Free Software Foundation, version 3 of the License.  *
  *                                                                         *
  ***************************************************************************/
 
@@ -28,11 +27,9 @@
 
 #include <QMessageBox>
 
-/*
 #include <Qt>
 #include <QShortcut>
 #include <QKeySequence>
-*/
 
 #include <QListWidget>
 #include <QAbstractItemView>
@@ -81,47 +78,54 @@ ActivityTagsForm::ActivityTagsForm(QWidget* parent): QDialog(parent)
 	connect(codePushButton, &QPushButton::clicked, this, &ActivityTagsForm::code);
 	connect(commentsPushButton, &QPushButton::clicked, this, &ActivityTagsForm::comments);
 
-	/*
-	QShortcut* addShortcut=new QShortcut(QKeySequence(Qt::Key_Plus), this);
-	connect(addShortcut, &QShortcut::activated, [=]{addActivityTagPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		addActivityTagPushButton->setToolTip(QString("+"));
-	//
-	QShortcut* modifyShortcut=new QShortcut(QKeySequence(Qt::Key_M), this);
-	connect(modifyShortcut, &QShortcut::activated, [=]{renameActivityTagPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		renameActivityTagPushButton->setToolTip(QString("M"));
-	//
-	QShortcut* removeShortcut=new QShortcut(QKeySequence::Delete, this);
-	connect(removeShortcut, &QShortcut::activated, [=]{removeActivityTagPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		removeActivityTagPushButton->setToolTip(QString("⌦"));
-	//
-	QShortcut* activateShortcut=new QShortcut(QKeySequence(Qt::Key_A), this);
-	connect(activateShortcut, &QShortcut::activated, [=]{activateActivityTagPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		activateActivityTagPushButton->setToolTip(QString("A"));
-	//
-	QShortcut* deactivateShortcut=new QShortcut(QKeySequence(Qt::Key_D), this);
-	connect(deactivateShortcut, &QShortcut::activated, [=]{deactivateActivityTagPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		deactivateActivityTagPushButton->setToolTip(QString("D"));
-	//
-	QShortcut* commentsShortcut=new QShortcut(QKeySequence(Qt::Key_C), this);
-	connect(commentsShortcut, &QShortcut::activated, [=]{commentsPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		commentsPushButton->setToolTip(QString("C"));
-	//
-	QShortcut* upShortcut=new QShortcut(QKeySequence(Qt::Key_U), this);
-	connect(upShortcut, &QShortcut::activated, [=]{moveActivityTagUpPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		moveActivityTagUpPushButton->setToolTip(QString("U"));
-	//
-	QShortcut* downShortcut=new QShortcut(QKeySequence(Qt::Key_J), this);
-	connect(downShortcut, &QShortcut::activated, [=]{moveActivityTagDownPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		moveActivityTagDownPushButton->setToolTip(QString("J"));
-	*/
+	if(SHORTCUT_PLUS){
+		QShortcut* addShortcut=new QShortcut(QKeySequence(Qt::Key_Plus), this);
+		connect(addShortcut, &QShortcut::activated, [=]{addActivityTagPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	addActivityTagPushButton->setToolTip(QString("+"));
+	}
+	if(SHORTCUT_M){
+		QShortcut* modifyShortcut=new QShortcut(QKeySequence(Qt::Key_M), this);
+		connect(modifyShortcut, &QShortcut::activated, [=]{renameActivityTagPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	renameActivityTagPushButton->setToolTip(QString("M"));
+	}
+	if(SHORTCUT_DELETE){
+		QShortcut* removeShortcut=new QShortcut(QKeySequence::Delete, this);
+		connect(removeShortcut, &QShortcut::activated, [=]{removeActivityTagPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	removeActivityTagPushButton->setToolTip(QString("⌦"));
+	}
+	if(SHORTCUT_A){
+		QShortcut* activateShortcut=new QShortcut(QKeySequence(Qt::Key_A), this);
+		connect(activateShortcut, &QShortcut::activated, [=]{activateActivityTagPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	activateActivityTagPushButton->setToolTip(QString("A"));
+	}
+	if(SHORTCUT_D){
+		QShortcut* deactivateShortcut=new QShortcut(QKeySequence(Qt::Key_D), this);
+		connect(deactivateShortcut, &QShortcut::activated, [=]{deactivateActivityTagPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	deactivateActivityTagPushButton->setToolTip(QString("D"));
+	}
+	if(SHORTCUT_C){
+		QShortcut* commentsShortcut=new QShortcut(QKeySequence(Qt::Key_C), this);
+		connect(commentsShortcut, &QShortcut::activated, [=]{commentsPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	commentsPushButton->setToolTip(QString("C"));
+	}
+	if(SHORTCUT_U){
+		QShortcut* upShortcut=new QShortcut(QKeySequence(Qt::Key_U), this);
+		connect(upShortcut, &QShortcut::activated, [=]{moveActivityTagUpPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	moveActivityTagUpPushButton->setToolTip(QString("U"));
+	}
+	if(SHORTCUT_J){
+		QShortcut* downShortcut=new QShortcut(QKeySequence(Qt::Key_J), this);
+		connect(downShortcut, &QShortcut::activated, [=]{moveActivityTagDownPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	moveActivityTagDownPushButton->setToolTip(QString("J"));
+	}
 
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
